# frozen_string_literal: true
module Hermes
  module Api
    module Rex
      class RexController < ::Api::D2::ApplicationController
        def for_lessor?
          for_lessor = params[:for_lessor]
          for_lessor.present? && ['true', true].include?(for_lessor)
        end

        def target_class_name
          for_lessor? ? 'lessor' : 'entity'
        end

        def from_parent_depth_param
          Integer(params[:parent_depth]) rescue 0
        end

        def max_depth_param
          Integer(params[:max_depth]) rescue -1
        end

        def class_target(for_lessor = nil)
          for_lessor ? Hermes::Lessor : Hermes::Entity
        end

        def from_id
          @from_id ||= params[:id]
        end

        def root_elements
          return render_json_error(:unprocessable_netity, :not_lessor) if current_user&.current_auth_role != "Bailleur" && for_lessor?

          root_ids = class_target(for_lessor?).readable_by(current_user)
                                              .pluck(:root_id)
                                              .uniq
                                              .compact ||
                     []
          render(
            jsonapi: class_target(for_lessor?).where(:id.in => root_ids),
            each_serializer: Hermes::Rex::RootElementSerializer
          )
        end

        def show
          return render_json_error(:unprocessable_entity, :missing_id_parameter) unless from_id.present?
          return render_json_error(:unprocessable_entity, :not_lessor) if current_user.current_auth_role != "Bailleur" && for_lessor?

          target_entity = Hermes::Entity.find_by(id: from_id)
          return render_json_error(:not_found, :object_not_found) if target_entity.blank?

          tree = target_entity.tree(
                                     from_parent_depth_param,
                                     max_depth_param,
                                     target_class_name,
                                     current_user,
                                     true
                                   )
          render(
            jsonapi: {
              data: Hermes::Rex::TreeSerializer.new(
                tree,
                root: true,
                scope: current_user,
                for_lessor: for_lessor?
              )
            }
          )
        end

        def current_user_roles
          current_user.attributes.slice(:roles, :auth_roles).values.flatten.uniq.compact
        end

        def current_user
          @user
        end
      end
    end
  end
end
