# frozen_string_literal: true

require 'rails_helper'
require 'vcr_config'


# exemple d'utilisation
# hr = Hermes::HousingRequest.first
# ho= Hermes::HousingOffer.first
# so=Hermes::BoClient::UpdateStatusTask.new({:'housing_request_id'=> hr.id,housing_offer_id: ho.id})
# so.to_xml
# so.execute

dir_path = File.dirname(__FILE__)
schema_path = [dir_path, 'RechercheDemande.xsd'].join('/')
require [Hermes::Engine.root, %w[lib hermes bo_client tasks]].flatten.join('/').to_s

RSpec.describe Hermes::BoClient::FindNudTask, type: :helper do
  let!(:xsd) { Nokogiri::XML::Schema(File.read(schema_path)) }
  let!(:user1) { create(:user) }
 

  it 'should load a valid XSD' do
    expect(xsd).to be_present
    expect(xsd.class).to be Nokogiri::XML::Schema
  end

  context 'with simple housing_request' do
    let!(:housing_request_initializer1) do
      create(:housing_request_initializer, unique_number: "1110220019793G1175")
    end
  
    let!(:find_nud_task1) do
      build(
        :find_nud_task,
        options: { housing_request_initializer_id: housing_request_initializer1.id.to_s }
      )
    end

    describe 'using to_xml' do
      it 'should return a valid xml' do
        puts find_nud_task1.to_xml
        ap find_nud_task1.validate_xml
        expect(xsd.validate(Nokogiri::XML(find_nud_task1.to_xml))).to eq([])
        xmlres = ""
        find_nud_task1.execute
        VCR.use_cassette("find_nud_task1", :match_requests_on => [:method, :uri, :path]) do
          perform_enqueued_jobs do
            enqueued_jobs.each {|job| xmlres =  job[:job].perform_now(*job[:args])}
          end
        end
        hri = Hermes::HousingRequestInitializer.create(unique_number: "ee")
        hri.xml_res = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?><ns1:interfaceNuu xmlns:ns1=\"http://nuu.application.i2/\" versionInterface=\"03.00\"><ns1:entete><ns1:typeFichier>DIS</ns1:typeFichier><ns1:dateFichier>2020-03-27T10:36:08</ns1:dateFichier></ns1:entete><ns1:demande><ns1:demandeLogement><ns1:numGuichet>G1175</ns1:numGuichet><ns1:numUnique>1110220019793G1175</ns1:numUnique><ns1:dateCreationDemande>2020-02-24</ns1:dateCreationDemande><ns1:forcerDoublon>false</ns1:forcerDoublon><ns1:renouvellementElec>false</ns1:renouvellementElec><ns1:precision></ns1:precision><ns1:ressourcesLoiEC>9600</ns1:ressourcesLoiEC><ns1:informationTraitement><ns1:estDelaiAnormalementLong>false</ns1:estDelaiAnormalementLong><ns1:estMultiplesAttributionsSousConditions>false</ns1:estMultiplesAttributionsSousConditions><ns1:dateCalculIndicateur>2020-03-22T00:00:00</ns1:dateCalculIndicateur></ns1:informationTraitement><ns1:logementRecherche><ns1:categorieLogementRecherche code=\"I\"/><ns1:avecParking>false</ns1:avecParking><ns1:rezDeChaussee>false</ns1:rezDeChaussee><ns1:sansAscenseur>false</ns1:sansAscenseur><ns1:demandeElargie>false</ns1:demandeElargie><ns1:listeTypeLogement><ns1:typeLogement code=\"T3\"/></ns1:listeTypeLogement><ns1:listeLocalisationSouhaite><ns1:localisationSouhaite><ns1:commune code=\"77349\"/><ns1:codePostal/><ns1:seuilEPCIPremierQuartile>9692</ns1:seuilEPCIPremierQuartile><ns1:quartileAppartenance>1</ns1:quartileAppartenance></ns1:localisationSouhaite></ns1:listeLocalisationSouhaite></ns1:logementRecherche><ns1:principauxMotifDemande><ns1:motifDemande code=\"01\"/></ns1:principauxMotifDemande><ns1:personnePhysique><ns1:demandeur><ns1:civilite code=\"2\"/><ns1:nom>LIBAR</ns1:nom><ns1:prenom>JOSSELINE</ns1:prenom><ns1:dateNaissance>1954-05-06</ns1:dateNaissance><ns1:nationalite code=\"1\"/><ns1:situationFamiliale code=\"C\"/><ns1:telPortable>0613498988</ns1:telPortable><ns1:notifSms>true</ns1:notifSms><ns1:notifEvt>false</ns1:notifEvt><ns1:adressePostale><ns1:etranger>false</ns1:etranger><ns1:numero>07</ns1:numero><ns1:voie>PLACE ILE DE RANCE</ns1:voie><ns1:codePostal>93150</ns1:codePostal><ns1:commune code=\"93007\"/></ns1:adressePostale><ns1:situationProfessionnelle><ns1:profession>VENDEUSE</ns1:profession><ns1:typeContratTravail code=\"CDIP\"/><ns1:nomEmployeurPrincipal>ZARA</ns1:nomEmployeurPrincipal><ns1:etranger>false</ns1:etranger><ns1:codePostal>75016</ns1:codePostal><ns1:commune code=\"75116\"/></ns1:situationProfessionnelle><ns1:revenuFiscal><ns1:anneeMoins2>2018</ns1:anneeMoins2><ns1:montantMoins2>5326</ns1:montantMoins2></ns1:revenuFiscal><ns1:listeRessourceRecue><ns1:detailRessource><ns1:ressource code=\"SAL\"/><ns1:montant>1200</ns1:montant></ns1:detailRessource></ns1:listeRessourceRecue><ns1:listeRessourceVersee/><ns1:listeRessourceRecuePersACharge/><ns1:listeRessourceVerseePersACharge/></ns1:demandeur><ns1:listePersonneACharge><ns1:personneACharge><ns1:nom>LIBAR</ns1:nom><ns1:prenom>KILLIANE</ns1:prenom><ns1:dateNaissance>1999-04-18</ns1:dateNaissance><ns1:sexe code=\"F\"/><ns1:lienParente code=\"E\"/></ns1:personneACharge></ns1:listePersonneACharge><ns1:logementActuel><ns1:listeModeleLogement><ns1:modeleLogement code=\"HCPE\"/></ns1:listeModeleLogement><ns1:montantMensuelLoyer>0</ns1:montantMensuelLoyer><ns1:montantMensuelAPL>0</ns1:montantMensuelAPL><ns1:nombreHabitant>6</ns1:nombreHabitant><ns1:typeLogementActuel code=\"T3\"/><ns1:surface>54</ns1:surface><ns1:proprietaire>false</ns1:proprietaire><ns1:etranger>false</ns1:etranger></ns1:logementActuel></ns1:personnePhysique></ns1:demandeLogement></ns1:demande></ns1:interfaceNuu>"
        
        hri.hydrate_housing_request_from_sne(user1.id)
        expect(hri.housing_request_id).not_to be(nil)
        ap housing_request_initializer1.reload.last_error_responses
        
        expect(housing_request_initializer1.reload.last_error_responses.length).to eq(0)
        expect(housing_request_initializer1.reload.last_send_has_error).to eq(false)
      end
    end
  end
end
